Site officiel de la Ville de Mons
Description: Actualités, événements, services en ligne, photos, vidéos... Tout sur Mons, capitale européenne de la culture en 2015!

Aller au contenu. | Aller à la navigation

- Plan du site
- Accessibilité
- Contact
- Se connecter

Chercher dans le site
Chercher par
Recherche avancée…

##### Thèmes

- Ma Ville
- Vivre à Mons
- Découvrir
- Culture
- Economie

##### Sections

- Info
Accès directs |
Administration
  L'Administration communale a mis en place un guichet électronique pour toutes vos démarches administratives en ligne |  | Services communaux Règlements Avis et enquêtes | Marchés publics Offres d’emploi Charte graphique
Vie politique
  La prochaine séance du Conseil communal se tiendra le 15 décembre 2015 à 18h à l'Hôtel de Ville. Séance publique. |  | Bourgmestre Collège Communal Conseil Communal | Procès-verbaux Interpellation
Lignes de vie
  Avoir des enfants Apprendre et se former Se loger |  | Travailler Vie de famille Seniors |
Utile
  Urgences et services de garde Transports en commun Enseignement |  | Repas scolaires du mois Espaces Publics Numériques Demande d'intervention (0800/92.329) | Vente de véhicules déclassés
Sites amis
  Accueil extra-scolaire Balade du cadeau original Télé MB |  | CPAS de Mons Gestion Centre-Ville Maison du Tourisme | Manège.Mons Police Pompiers
Actualités |
Evénements |
Fééries de Noël à Mons ! Publié le 02/12/2015 L'émerveillement sera au rendez-vous du 5 décembre au 3 janvier 2016 à Mons avec la traditionnel MONS CŒUR EN NEIGE. Une édition spéciale vintage et jeux vidéo avec de nombreuses animations et surprises vous y attendent...
Mons 2015 passe le cap des deux millions de visiteurs ! Publié le 25/11/2015 Mons 2015 a passé, mardi, le cap des deux millions de visiteurs, soit l'objectif de fréquentation fixé par la Fondation Mons 2015 avant le lancement de l'année de la Capitale européenne de la Culture.
Activités et stages des vacances d'hiver 2015 Publié le 24/11/2015 A Mons, pour les enfants âges entre 2,5 ans et 12 ans, découvrez la brochure des activités et stages culturels, artistiques, sportifs et ludiques.
L’Alhambra reçoit le label « Quality Nights »! Publié le 10/11/2015 Cette salle de concert, après avoir formé son personnel et mis en place des services utiles à la santé des fêtards, a officialisé son adhésion au label Quality Nights le 7 novembre dernier lors de la soirée du Rockerill.
Semaine prévention cambriolages ! Publié le 09/11/2015 Dans le cadre de l'action nationale "1 JOUR SANS CAMBRIOLAGE", le Service de Prévention de la Ville de Mons et la ZP Mons/Quévy vous sensibilisent dès ce lundi 9 novembre sur les mesures préventives pour ce type de vol.
Projet de charte associative montoise ! Publié le 30/10/2015 Participez à la construction d'une charte de valeurs et d'engagement pour toutes les associations de Mons. Faites nous part de vos IDEES et SUGGESTIONS jusqu'au 11 décembre 2015.
Voir toutes les actualités | Divertissement LES DIMANCHES AU THEATRE du 11/10/2015 au 17/04/2016 Et si vous passiez votre dimanche après-midi au théâtre ? Découvrez le programme de la saison 2015-2016 de "Mons Divertissement" au Théâtre Royal de Mons ! Spectacles grand public. Exposition VERLAINE, CELLULE 252 / TURBULENCES POÉTIQUES du 17/10/2015 au 24/01/2016 C'est l’histoire de Verlaine et de la Belgique. Comme un roman épique, cette exposition vous emmènera dans un « cheminement Verlaine » à travers l’homme et ses textes, à partir de nombreux documents originaux et exceptionnels. Exposition LIGHT OF HOUSE du 24/10/2015 au 17/01/2016 Entrez dans la Light House, une maison qui deviendra, le temps de l’exposition, le théâtre d’un « son et lumière » incarnant son improbable vécu. Exposition PRIX EUROPEENS DES ARTS APPLIQUES du 24/10/2015 au 10/01/2016 Résultat d’un concours international, l’exposition présente 78 créateurs provenant de 18 pays. Toutes les disciplines de l’art appliqué et du design artisanal sont représentées : céramique, verre, bijou, mobilier, textile… Exposition REGARDS 14-18 du 06/11/2015 au 03/01/2016 Peinture, sculpture, gravure, installation vidéo, œuvres collectives éphémères : huit jeunes artistes européens, en résidence au MMM, s’expriment pour créer, à l’issue d’ateliers et de réflexions conjointes, des œuvres communes sur la thématique de la Première Guerre mondiale. Divertissement FOIRE D'AUTOMNE du 06/11/2015 au 06/12/2015 La traditionnelle foire de Mons attend petits et grands ! Cette année, complémentairement à la Grand'Place, un nouveau champs de foire se tiendra sur l'Esplanade des Congrès face au MICX. Facile d'accès en voiture (parkings à proximité) et par la passerelle piétonne de la gare. HOMMAGE ARTISTIQUE A LA GRANDE GUERRE / Les jeunes européens s’expriment du 07/11/2015 au 03/01/2016 Une dizaine de jeunes artistes résidant en France, en Allemagne, au Royaume-Uni et en Wallonie ou à Bruxelles, se réuniront en résidence au Mons Memorial Museum. Leur objectif : créer, à l’issue d’ateliers et de réflexions conjointes, des oeuvres communes sur la thématique de la Première Guerre mondiale, des oeuvres témoins de la mémoire contrastée du conflit en Europe. Exposition CÉDRIC GERBEHAYE / D’ENTRE EUX du 07/11/2015 au 03/01/2016 Par le biais de recherches photographiques et de rencontres, le photographe documentaire, membre de l’Agence VU’, explore la Belgique sous l’angle du fait quotidien. Exposition D'ENTRE EUX / CEDRIC GERBEHAYE du 11/11/2015 au 03/01/2016 Cédric Gerbehaye utilise la photographie comme outil d’analyse, comme un instrument qui, s’il ne démontre rien, permet de pointer les questions véritables et d’ouvrir les esprits et les sensibilités. Voir tous les événements
  | Plan interactif Focus Démarches administratives Agenda thématique Mons en images Travaux en cours Mons, ville durable A voir ! Doudou (site officiel) (c)Gregory Mathelot Pôle muséal (site officiel) Mons 2015 (site officiel)
  Suivez-nous
Tweets de @VilledeMons